@@ -136,19 +136,11 @@ module Spec
     end
 
     def default_bundle_path(*path)
-      if Bundler.feature_flag.bundler_4_mode?
-        local_gem_path(*path)
-      else
-        system_gem_path(*path)
-      end
+      system_gem_path(*path)
     end
 
     def default_cache_path(*path)
-      if Bundler.feature_flag.global_gem_cache?
-        home(".bundle/cache", *path)
-      else
-        default_bundle_path("cache/bundler", *path)
-      end
+      default_bundle_path("cache/bundler", *path)
     end
 
     def compact_index_cache_path
@@ -342,7 +334,7 @@ module Spec
     end
 
     def man_tracked_files_glob
-      ruby_core? ? "man/bundle* man/gemfile*" : "lib/bundler/man/bundle*.1 lib/bundler/man/gemfile*.5"
+      "lib/bundler/man/bundle*.1.ronn lib/bundler/man/gemfile*.5.ronn"
     end
 
     def ruby_core_tarball?
