@@ -21,20 +21,11 @@ class Gem::UnknownCommandError < Gem::Exception
   end
 
   def self.attach_correctable
-    return if defined?(@attached)
+    return if method_defined?(:corrections)
 
-    if defined?(DidYouMean::SPELL_CHECKERS) && defined?(DidYouMean::Correctable)
-      if DidYouMean.respond_to?(:correct_error)
-        DidYouMean.correct_error(Gem::UnknownCommandError, Gem::UnknownCommandSpellChecker)
-      else
-        DidYouMean::SPELL_CHECKERS["Gem::UnknownCommandError"] =
-          Gem::UnknownCommandSpellChecker
-
-        prepend DidYouMean::Correctable
-      end
+    if defined?(DidYouMean) && DidYouMean.respond_to?(:correct_error)
+      DidYouMean.correct_error(Gem::UnknownCommandError, Gem::UnknownCommandSpellChecker)
     end
-
-    @attached = true
   end
 end
 
