@@ -111,10 +111,8 @@ class Release
 
   def self.install_dependencies!
     system(
-      "ruby",
-      "-I",
-      File.expand_path("../lib", __dir__),
-      File.expand_path("../bundler/spec/support/bundle.rb", __dir__),
+      { "RUBYOPT" => "-I#{File.expand_path("../lib", __dir__)}" },
+      File.expand_path("../bundler/bin/bundle", __dir__),
       "install",
       "--gemfile=#{File.expand_path("bundler/release_gems.rb", __dir__)}",
       exception: true
